      SUBROUTINE SOLAR1(OB,ECC,PER,NY,NT,COSY,SINY,TANY,OMEGA,SOLIRR,
     +COSZ)
C
C         THIS SUBROUTINE COMPUTES THE MEAN DAILY SOLAR IRRADIANCE AT THE
C         TOP OF THE ATMOSPHERE AS A FUNCTION OF LATITUDE AND TIME OF YEAR
C         GIVEN THE OBLIQUITY OF THE EARTH'S AXIS, THE ECCENTRICITY OF THE
C         EARTH'S ORBIT, AND THE ANGLE FROM PERIHELION TO THE VERNAL
C         EQUINOX.
C         COSDEC = COSINE OF THE SOLAR DECLINATION
C         COSY   = COSINES OF THE LATITUDES OF THE GRID POINTS
C         COSZ   = COSINE OF THE MEAN ZENITH ANGLE
C         DT     = TIME STEP SIZE
C         ECC    = ECCENTRICITY OF THE EARTH'S ORBIT
C         E      = INVERSE SQUARED ADJUSTMENT TO THE SOLAR CONSTANT
C         OB     = OBLIQUITY OF THE EARTH'S AXIS
C         OMEGA  = POSITION OF THE EARTH IN ORBIT AS A FUNCTION OF TIME
C         R      = EARTH-SUN DISTANCE
C         SINDEC = SINE OF THE SOLAR DECLINATION
C         SINY   = SINES OF THE LATITUDES OF THE GRID POINTS
C         SOLIRR = SOLAR IRRADIANCE
C         TANDEC = TANGENT OF THE SOLAR DECLINATION
C         TANY   = TANGENTS OF THE LATITUDES OF THE GRID POINTS
C
C         DECLARE THE VARIABLES
C
C         DECLARE THE LOCAL VARIABLES
      INTEGER J,L,NY,NT
      REAL COSDEC,COSY(NY),COSZ(NY,NT),DT,ECC,ECCFAC,E,EZERO,OB,OMEGA
     +(NT),OMGPER,PER,PI,R,SINDEC,SINY(NY),SOLIRR(NY,NT),TANDEC,TANY(NY)
     +,TZERO,T1,T2,T3,T4,Z
C
C         DEFINE STATEMENT FUNCTIONS
C
      ORBFUN(OMEGA1) = RZERO*(1.-(ECC*COS(OMEGA1)))**2
C
C         COMPUTE THE SOLAR IRRADIANCE
C
C         SET NUMERICAL CONSTANTS
      PI = ACOS(-1.0)
      EZERO = 1./PI
      ECCFAC = 1.-ECC**2
      RZERO = 2.*PI/(ECCFAC**1.5)
      SINOB = SIN(OB)
      DT = 1./NT
C
C         ITERATE AROUND THE ORBIT TO FIND THE ANGLE FROM PERIHELION AS
C         A FUNCTION OF TIME
      OMEGA(1) = 0.0
      DO 10 L=2,NT
        OMGPER = OMEGA(L-1)-PER
        T1 = DT*ORBFUN(OMGPER)
        T2 = DT*ORBFUN(OMGPER+(.5*T1))
        T3 = DT*ORBFUN(OMGPER+(.5*T2))
        T4 = DT*ORBFUN(OMGPER+T3)
        OMEGA(L) = OMEGA(L-1)+(1./6.)*(T1+2.*T2+2.*T3+T4)
   10 CONTINUE
C
C         COMPUTE THE SOLAR FLUX AS A FUNCTION OF TIME AND LATITUDE
      DO 30 L=1,NT
        SINDEC = SINOB*SIN(OMEGA(L))
        COSDEC = SQRT(1.-SINDEC**2)
        TANDEC = SINDEC/COSDEC
        R = ECCFAC/(1.-(ECC*COS(OMEGA(L)-PER)))
        E = EZERO/R**2
        DO 20 J=1,NY
          Z = -TANY(J)*TANDEC
          IF (Z.GE.1.) THEN
            SOLIRR(J,L) = 0.
            COSZ(J,L) = 0.
          ELSE
            IF (Z.LE.-1.)  Z = -.999999
            TZERO = ACOS(Z)
            SOLIRR(J,L) = E*((TZERO*SINY(J)*SINDEC)+(COSY(J)*COSDEC*SIN
     +      (TZERO)))
            COSZ(J,L) = PI*SOLIRR(J,L)/TZERO
          ENDIF
   20   CONTINUE
   30 CONTINUE
      END